/**
 * Created by Sand on 2016/11/14.
 */
"use strict";

var express = require("express");
var router = express.Router();

var APIv1 = require('../include/endpoints').APIv1;

var group = require('../models/group');

/**
 * 获取成员头像。每个组最多返回5个成员的头像。
 *
 * 请求URL：
 *  /groups/member/avatars?groups=433,10,63
 */
router.get(APIv1.Groups.MembersAvatar, function (req, res) {
    var groups = req.query.groups;
    if (!groups) {
        throw {httpStatus: 406, message: "Missing field: groups"};
    }

    var tokens = groups.split(",");
    groups = "'" + tokens.join("', '") + "'";

    var avatars = [];
    group.getMembersAvatar(groups, function (err, rows) {
        if(err){
            console.log("Get group member's avatar list failed: ", err);

            res.status(500).send({message: "Get group member's avatar list failed."});
            return;
        }

        var indexInGroup = 0;
        var lastGroupCode = '';
        var lastGroup;
        for (var i = 0; i < rows.length; ++i) {
            if(indexInGroup >= 5) continue;

            var row = rows[i];
            var groupCode = row.g_code;
            if (lastGroupCode !== groupCode) {
                indexInGroup = 0;
                lastGroupCode = groupCode;
                lastGroup = {groupCode: groupCode, avatars: []};

                if(lastGroupCode !== ''){
                    avatars.push(lastGroup);
                }
            }

            lastGroup.avatars.push({
                code: row.dr_code,
                name: row.dr_name,
                avatar: row.dr_photo.length === 0 ? "" : row.dr_photo
            });

            indexInGroup = indexInGroup + 1;
        }

        res.status(200).send(avatars);
    });
});

module.exports = router;