/**
 * 群组模型。此数据来源于家庭医生平台数据库的行政团队。
 *
 * 实际团队数据分为两部分：行政团队与临时讨论组，具体的与业务相关。医生在讨论组里，
 * 会出现两种：在行政团队内聊天，也可以在临时讨论组里聊天。
 */
"use strict";

var wlyyRepo = require("../repository/wlyy.repo");
var GROUP_TYPE = require('../include/commons').GROUP_TYPE;

/**
 * 判断是否为团队成员。
 *
 * @param groupId
 * @param groupType
 * @param doctorId
 * @param handler
 */
exports.isGroupMember = function(groupId, groupType, doctorId, handler){
    if(groupType == GROUP_TYPE.AdminTeam) {
        wlyyRepo.execQuery({
            "sql": "SELECT doctor_code user_id from wlyy_admin_team_member WHERE team_id=? and doctor_code=?",
            "args": [groupId, doctorId],
            "handler": handler
        });
    }else {
        wlyyRepo.execQuery({
            "sql": "SELECT member_code user_id from wlyy_talk_group_member WHERE group_code=? and member_code=?",
            "args": [groupId, doctorId],
            "handler": handler
        });
    }
};

/**
 * 获取团队成员。
 *
 * @param groupId
 * @param groupType
 * @param handler
 */
exports.getMembers = function(groupId, groupType, handler) {
    if(groupType == GROUP_TYPE.AdminTeam) {
        wlyyRepo.execQuery({
            "sql": "SELECT doctor_code user_id from wlyy_admin_team_member WHERE team_id=? AND available = 1",
            "args": [groupId],
            "handler": handler
        });
    } else {
        wlyyRepo.execQuery({
            "sql": "SELECT member_code user_id from wlyy_talk_group_member WHERE group_code=?",
            "args": [groupId],
            "handler": handler
        });
    }
};

exports.getMembersAvatar = function (groups, handler) {
    var sql = "SELECT * FROM(" +
        "SELECT g.code g_code, d.code dr_code, d.name dr_name, d.photo dr_photo " +
        "FROM wlyy.wlyy_talk_group g, wlyy.wlyy_talk_group_member m, wlyy.wlyy_doctor d " +
        "WHERE g.code = m.group_code AND m.member_code = d.code AND g.code in(" + groups + ") AND d.photo is NOT null " +
        " UNION " +
        "SELECT g.id g_code, d.code dr_code, d.name dr_name, d.photo dr_photo " +
        "FROM wlyy.wlyy_admin_team g, wlyy.wlyy_admin_team_member m, wlyy.wlyy_doctor d " +
        "WHERE g.id = m.team_id AND m.doctor_code = d.code AND g.id in(" + groups + ") AND d.photo is NOT null " +
        ") x ORDER BY x.g_code";

    wlyyRepo.execQuery({
        "sql": sql,
        "args": [],
        "handler": handler
    });
};
